package com.msl.java;

import com.msl.FileContext;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author wanglq
 * Date 2024/8/7
 * Time 9:01
 */
public class FeignClassAnnotationUpdater implements FeignUpdater {
    private final Pattern pattern = Pattern.compile("@FeignClient\\(name\\s*=\\s*\"([^\"]+)\"\\)\\s+@RequestMapping\\(\"([^\"]+)\"\\)");

    /**
     * 更新文件上下文
     *
     * @param context 文件上下文
     */
    @Override
    public void update(FileContext context) {
        context.setContent(replaceAnnotation(context.getContent()));
    }

    private String replaceAnnotation(String content) {
        Matcher matcher = pattern.matcher(content);
        if (matcher.find()) {
            // 获取第一个捕获组的值，即 服务名
            String nameValue = matcher.group(1);
            // 获取第二个捕获组的值，即 路径
            String pathValue = matcher.group(2);

            // 构造替换后的注解内容
            String replaced = String.format("@FeignClient(name = \"%s\", path = \"%s\")", nameValue, pathValue);

            // 替换原始文本中匹配的部分
            return matcher.replaceFirst(replaced);
        }
        // 如果没有匹配到则返回原始输入
        return content;
    }

}
