package com.msl.java;

import com.msl.FileContext;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author wanglq
 * Date 2024/8/7
 * Time 9:06
 */
public class FeignMethodAnnotationUpdater2 implements FeignUpdater {
    public final Pattern pattern = Pattern.compile("@RequestMapping\\(value = \"([^\"]+)\",\\s+method = RequestMethod.(GET|POST)\\)");

    public static void main(String[] args) {
        // 原始的方法上注解内容
        String originalAnnotation = "  12341234  @RequestMapping(value = \"/uploadBase64\", method = RequestMethod.POST)\n" +
                "   adf @RequestMapping(value = \"/uploadBase64111\", method = RequestMethod.POST)\n" +
                "   3241zsdf1234 @RequestMapping(value = \"/uploadBase642222\", method = RequestMethod.POST)";

        // 替换后的内容
        String replacedAnnotation = new FeignMethodAnnotationUpdater2().replaceAnnotation(originalAnnotation);

        System.out.println("替换后的注解内容：");
        System.out.println(replacedAnnotation);
    }


    /**
     * 更新文件上下文
     *
     * @param context 文件上下文
     */
    @Override
    public void update(FileContext context) {
        context.setContent(replaceAnnotation(context.getContent()));
    }

    public String replaceAnnotation(String input) {
        StringBuffer sb = new StringBuffer();
        Matcher matcher = pattern.matcher(input);
        while (matcher.find()) {
            // 获取第一个捕获组的值，即 "/msl-user/product/listProducts"
            String pathValue = matcher.group(1);
            // 获取第二个捕获组的值，即 "POST"
            String methodValue = matcher.group(2);

            // 构造替换后的注解内容
            String annotationType = methodValue.equals("GET") ? "@GetMapping" : "@PostMapping";
            String replaced = String.format("%s(\"%s\")", annotationType, pathValue);

            // 替换原始文本中匹配的部分
            matcher.appendReplacement(sb, replaced);
        }
        // 将剩余部分追加到结果中
        matcher.appendTail(sb);
        // 如果没有匹配到则返回原始输入
        return sb.toString();
    }
}
