package com.msl.java;

import com.google.common.collect.Lists;
import com.msl.FileContext;
import com.msl.NormalUpdater;
import org.javatuples.Pair;

import java.util.List;

/**
 * @author wanglq
 * Date 2024/8/7
 * Time 14:05
 */
public class JavaNormalUpdater extends NormalUpdater {
    public static final List<Pair<String, String>> LIST = Lists.newArrayList();

    static {
        // javax 相关
        LIST.add(Pair.with("import javax.servlet", "import jakarta.servlet"));
        LIST.add(Pair.with("import javax.validation", "import jakarta.validation"));

        // swagger 相关
        LIST.add(Pair.with("import io.swagger.annotations.ApiModelProperty;", "import io.swagger.v3.oas.annotations.media.Schema;"));
        LIST.add(Pair.with("@ApiModelProperty(value", "@Schema(description"));
        LIST.add(Pair.with("@ApiModelProperty(\"", "@Schema(description=\""));
        LIST.add(Pair.with("@ApiModelProperty(hidden = true)", "@Schema(hidden = true)"));

        LIST.add(Pair.with("import io.swagger.annotations.Api;", "import io.swagger.v3.oas.annotations.tags.Tag;"));
        LIST.add(Pair.with("@Api(value", "@Tag(name"));
        LIST.add(Pair.with("@Api(tags", "@Tag(name"));

        LIST.add(Pair.with("import io.swagger.annotations.ApiOperation;", "import io.swagger.v3.oas.annotations.Operation;"));
        LIST.add(Pair.with("@ApiOperation(value", "@Operation(summary"));
        LIST.add(Pair.with("@ApiOperation(\"", "@Operation(summary = \""));
        LIST.add(Pair.with("notes = \"", "description = \""));

        LIST.add(Pair.with("import io.swagger.annotations.ApiParam;", "import io.swagger.v3.oas.annotations.Parameter;"));
        LIST.add(Pair.with("@ApiParam(\"", "@Parameter(name = \""));

    }


    @Override
    protected List<Pair<String, String>> replaceList() {
        return LIST;
    }

    /**
     * 能否更新文件
     *
     * @param context 文件上下文
     * @return 能否更新
     */
    @Override
    public boolean canApply(FileContext context) {
        return context.getFileName().endsWith(".java");
    }
}
